HoldOnPopOverlayEntries class

This class contains static methods for creating overlay entries for displaying popups in a Flutter app.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

customPopup({required Widget child}) OverlayEntry
Returns an OverlayEntry with a custom popup that displays a child widget.
customPositionPopup({required Widget child, required Offset position}) OverlayEntry
Returns an OverlayEntry with a custom position popup that displays a child widget at a specific position on the screen.
defaultPopup({required Widget child}) OverlayEntry
Returns an OverlayEntry with a default popup that displays a semi-transparent background with a blur effect and an animated child widget.